@@ -171,6 +171,7 @@ auk_filter.auk_ebd <- function(x, file, file_sampling, keep, drop, awk_file,
   } else if (!missing(drop)) {
     drop <- tolower(drop)
     drop <- stringr::str_replace_all(drop, "_", " ")
+    drop <- stringr::str_replace_all(drop, "/", " ")
     stopifnot(all(drop %in% x$col_idx$name))
     if (any(must_keep %in% drop)) {
       m <- paste("The following columns must be retained:",
@@ -436,8 +437,10 @@ awk_translate <- function(filters, col_idx, sep, select) {
     filter_strings$date_substr <- sprintf("monthday = substr($%i, 6, 5)", idx)
     # remove the wildcard part of date
     dates <- stringr::str_replace(filters$date, "^\\*-", "")
-    condition <- str_interp("monthday >= \"${mn}\" && monthday <= \"${mx}\"",
-                            list(mn = dates[1], mx = dates[2]))
+    lo_wrap = if (attr(filters$date, "wrap")) "||" else "&&"
+    condition <- str_interp("monthday >= \"${mn}\" ${lo} monthday <= \"${mx}\"",
+                            list(mn = dates[1], mx = dates[2],
+                                 lo = lo_wrap))
     filter_strings$date <- str_interp(awk_if, list(condition = condition))
   } else {
     filter_strings$date_substr <- ""
